==> xlnl-3.3.4.tar.gz: xlnl-3.3.4/src/mnstr.h <==
/***************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: mnstr.h,v 1.36 2008/01/11 09:12:57 bowkenken Exp $
***************************************************************/

#ifndef	MNSTR_H
#define	MNSTR_H

/***************************************************************
* 󥹥
***************************************************************/

#include	"chr.h"
#include	"mnstr-kind.h"

/* 󥹥ο */

/*  */
#define	MNSTR_MAX_N	128
/* ʿѽи */
#define	MNSTR_AVE_N	16

/* 󥹥ư롢Υκ */
#define	MNSTR_MOVE_MAX_X	(AREA_MAX_X * 4 + 0)
#define	MNSTR_MOVE_MAX_Y	(AREA_MAX_Y * 4 + 0)

/* ᤤȽǤΥ */
#define	MNSTR_NEAR_R	4

/* 󥹥ɤݤȥСΥ٥뤬夬뤫ܰ */
#define	EXP_NEED_KILL_MNSTR_N	20

/* 󥹥ƥΨ */
#define	ITEM_DROP_RATE_100	((rate_t)100)

#define	ITEM_DROP_RATE_AAA	((rate_t)90)
#define	ITEM_DROP_RATE_AA	((rate_t)80)
#define	ITEM_DROP_RATE_A	((rate_t)70)

#define	ITEM_DROP_RATE_BBB	((rate_t)60)
#define	ITEM_DROP_RATE_BB	((rate_t)50)
#define	ITEM_DROP_RATE_B	((rate_t)40)

#define	ITEM_DROP_RATE_CCC	((rate_t)30)
#define	ITEM_DROP_RATE_CC	((rate_t)20)
#define	ITEM_DROP_RATE_C	((rate_t)10)

#define	ITEM_DROP_RATE_DDD	((rate_t)5)
#define	ITEM_DROP_RATE_DD	((rate_t)3)
#define	ITEM_DROP_RATE_D	((rate_t)1)

#define	ITEM_DROP_RATE_0	((rate_t)0)

/***************************************************************
* ǡ
***************************************************************/

/* 󥹥Υǡ */

typedef chr_t	mnstr_t;

/* 󥹥Τʤ򹶷⤷Υߡ */

typedef struct {
	long	x, y;
} mnstr_null_t;

/* 󥹥νиΥǡ */

typedef struct {
	/* 󥹥μ */
	mnstr_kind_t	kind;

	/* ȯ볬κǾκʬ */
	long	add_lev, range_lev;

	/* ȯ볬κǾ */
	/* ؿǼư׻ */
	long	min_lev, max_lev;
} mnstr_lev_tab_t;

#endif	/* MNSTR_H */

==> xlnl-3.3.5.tar.gz: xlnl-3.3.5/src/mnstr.h <==
/***************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: mnstr.h,v 1.37 2008/10/07 08:29:52 bowkenken Exp $
***************************************************************/

#ifndef	MNSTR_H
#define	MNSTR_H

/***************************************************************
* 󥹥
***************************************************************/

#include	"chr.h"
#include	"mnstr-kind.h"

/* 󥹥ο */

/*  */
#define	MNSTR_MAX_N	128
/* ʿѽи */
#define	MNSTR_AVE_N	16

/* 󥹥ư롢Υκ */
#define	MNSTR_MOVE_MAX_X	(AREA_MAX_X * 4 + 0)
#define	MNSTR_MOVE_MAX_Y	(AREA_MAX_Y * 4 + 0)

/* ᤤȽǤΥ */
#define	MNSTR_NEAR_R	4

/* 󥹥ɤݤȥСΥ٥뤬夬뤫ܰ */
#define	EXP_NEED_KILL_MNSTR_N	20

/* 󥹥ƥΨ */
#define	ITEM_DROP_RATE_100	((rate_t)100)

#define	ITEM_DROP_RATE_AAA	((rate_t)90)
#define	ITEM_DROP_RATE_AA	((rate_t)80)
#define	ITEM_DROP_RATE_A	((rate_t)70)

#define	ITEM_DROP_RATE_BBB	((rate_t)60)
#define	ITEM_DROP_RATE_BB	((rate_t)50)
#define	ITEM_DROP_RATE_B	((rate_t)40)

#define	ITEM_DROP_RATE_CCC	((rate_t)30)
#define	ITEM_DROP_RATE_CC	((rate_t)20)
#define	ITEM_DROP_RATE_C	((rate_t)10)

#define	ITEM_DROP_RATE_DDD	((rate_t)5)
#define	ITEM_DROP_RATE_DD	((rate_t)3)
#define	ITEM_DROP_RATE_D	((rate_t)1)

#define	ITEM_DROP_RATE_0	((rate_t)0)

/***************************************************************
* ǡ
***************************************************************/

/* 󥹥Υǡ */

typedef chr_t	mnstr_t;

/* 󥹥Τʤ򹶷⤷Υߡ */

typedef struct {
	long	x, y;
} mnstr_null_t;

/* 󥹥νиΥǡ */

typedef struct {
	/* 󥹥μ */
	mnstr_kind_t	kind;

	/* ȯ볬κǾκʬ */
	long	add_lev, range_lev;

	/* ȯ볬κǾ */
	/* ؿǼư׻ */
	long	min_lev, max_lev;
} mnstr_lev_tab_t;

/* 饹ܥμ */

typedef enum {
	LAST_BOSS_KIND_NULL,
	LAST_BOSS_KIND_EXEL,
	LAST_BOSS_KIND_EXELER,
	LAST_BOSS_KIND_XEX,
	LAST_BOSS_KIND_MAX_N,
} last_boss_kind_t;

#endif	/* MNSTR_H */
